package com.dsk.biz.service;


import com.dsk.biz.domain.BusinessFollowRecord;
import com.dsk.biz.domain.bo.BusinessIdDto;
import com.dsk.biz.domain.bo.BusinessListDto;
import com.dsk.biz.domain.vo.BusinessListVo;
import com.dsk.common.core.domain.PageQuery;
import com.dsk.common.core.page.TableDataInfo;

import java.util.List;

/**
 * 项目跟进记录Service接口
 *
 * @author lxl
 * @date 2023-05-17
 */
public interface IBusinessFollowRecordService
{
    /**
     * 查询项目跟进记录
     *
     * @param id 项目跟进记录主键
     * @return 项目跟进记录
     */
    public BusinessFollowRecord selectBusinessFollowRecordById(Long id);

    /**
     * 根据项目id查询项目跟进记录
     *
     * @param dto 项目跟进记录
     * @return 项目跟进记录集合
     */
    public TableDataInfo<BusinessFollowRecord> selectBusinessFollowRecordList(BusinessIdDto dto, PageQuery pageQuery);

    /**
     * 分页查询跟进动态
     *
     * @param dto
     * @return
     */
    TableDataInfo<BusinessFollowRecord> allFollow(BusinessListDto dto, PageQuery pageQuery);

    /**
     * 分页查询项目跟进记录列表
     *
     * @param businessFollowRecord 项目跟进记录
     * @return 项目跟进记录集合
     */
    public List<BusinessFollowRecord> businessFollowRecordPaging(BusinessFollowRecord businessFollowRecord);

    /**
     * 新增项目跟进记录
     *
     * @param businessFollowRecord 项目跟进记录
     * @return 结果
     */
    public int insertBusinessFollowRecord(BusinessFollowRecord businessFollowRecord);

    /**
     * 查询关联项目
     * @param userId
     * @return
     */
    List<BusinessListVo> selectRelateProject(Long userId);

    /**
     * 查询关联业主企业
     * @param userId
     * @return
     */
    List<String> selectRelateCompany(Long userId);

    /**
     * 修改项目跟进记录
     *
     * @param businessFollowRecord 项目跟进记录
     * @return 结果
     */
    public int updateBusinessFollowRecord(BusinessFollowRecord businessFollowRecord);

    /**
     * 批量删除项目跟进记录
     *
     * @param ids 需要删除的项目跟进记录主键集合
     * @return 结果
     */
    public int deleteBusinessFollowRecordByIds(Long[] ids);

    /**
     * 删除项目跟进记录信息
     *
     * @param id 项目跟进记录主键
     * @return 结果
     */
    public int deleteBusinessFollowRecordById(Long id);
}
